@@ -20,20 +20,24 @@
 pub mod bench;
 pub mod cat;
 pub mod cp;
+pub mod edit;
 pub mod ls;
 pub mod mv;
 pub mod rm;
 pub mod stat;
+pub mod tee;
 
 #[derive(Debug, clap::Subcommand)]
 pub enum OliSubcommand {
     Bench(bench::BenchCmd),
     Cat(cat::CatCmd),
     Cp(cp::CopyCmd),
+    Edit(edit::EditCmd),
     Ls(ls::LsCmd),
     Rm(rm::RmCmd),
     Stat(stat::StatCmd),
     Mv(mv::MoveCmd),
+    Tee(tee::TeeCmd),
 }
 
 impl OliSubcommand {
@@ -42,10 +46,12 @@ impl OliSubcommand {
             Self::Bench(cmd) => cmd.run(),
             Self::Cat(cmd) => cmd.run(),
             Self::Cp(cmd) => cmd.run(),
+            Self::Edit(cmd) => cmd.run(),
             Self::Ls(cmd) => cmd.run(),
             Self::Rm(cmd) => cmd.run(),
             Self::Stat(cmd) => cmd.run(),
             Self::Mv(cmd) => cmd.run(),
+            Self::Tee(cmd) => cmd.run(),
         }
     }
 }
